unit raEditor;

interface

uses Classes, SysUtils, Controls, Forms, dbPanel, fmFields, dbSearch, QRaCtrls,
     {$IFDEF VER140}
     DesignEditors, Designintf
     {$ELSE}
     Dsgnintf
     {$ENDIF};

type
  TFieldsProperty = class(TStringProperty)
  public
    function GetAttributes: TPropertyAttributes; override;
    procedure GetValues(Proc: TGetStrProc); override;
  end;

  TFieldsEditor = class(TComponentEditor)
  public
    function GetVerbCount: Integer; override;
    function GetVerb(Index: Integer): String; override;
    procedure ExecuteVerb(Index: Integer); override;
  end;

  TQRaFieldsProperty = class(TStringProperty)
  public
    function GetAttributes: TPropertyAttributes; override;
    procedure GetValues(Proc: TGetStrProc); override;
  end;

implementation

{TFieldsProperty}
function TFieldsProperty.GetAttributes: TPropertyAttributes;
begin
 Result := [paValueList];
end;

procedure TFieldsProperty.GetValues(Proc: TGetStrProc);
var i: Integer;
    AField: TRaDBPanelField;
begin
   AField := GetComponent(0) as TRaDBPanelField;
   if AField <> nil then
   with AField.DBEditField do
   begin
    if (DataSource <> nil) and (DataSource.DataSet <> nil) then
      for i := 0 to DataSource.DataSet.FieldCount-1 do
        Proc(DataSource.DataSet.Fields[i].FieldName);
  end;
end;

{TFieldsEditor}
function TFieldsEditor.GetVerbCount: Integer;
begin
   Result := 1;
end;

function TFieldsEditor.GetVerb(Index: Integer): String;
begin
   case Index of
     0: Result := '&Define fields';
   end;
end;

procedure TFieldsEditor.ExecuteVerb(Index: Integer);
var Dialog: TfmGetFields;
    SearchComponent: TRaDBSearch;
    i: Integer;
    AList: TList;
begin
   case Index of
      0:
        begin
           SearchComponent := Component as TRaDBSearch;
           AList := TList.Create;
           try
             for i := 0 to SearchComponent.Fields.Count-1 do
               if SearchComponent.Fields[i].Field <> nil then
                 AList.Add(SearchComponent.Fields[i].Field);
               Dialog := TFmGetFields.CreateWithDataSet(Application,
                                                    SearchComponent.DataSet,
                                                    AList);
             Dialog.Caption := Format('%s.%sFields', [Component.Owner.Name,
                                                    Component.Name]);
             try
               if Dialog.ShowModal = mrOk then
               with Dialog.lbSelFields do
               begin
                  SearchComponent.Fields.Clear;
                  for i := 0 to Items.Count-1 do
                     SearchComponent.Fields.Add.FieldName := Items[i];
                  Designer.Modified;
               end;
             finally
               Dialog.Free;
             end;
           finally
             AList.Free;
           end;
        end;
   end;
end;

{ TQRaFieldsProperty }
function TQRaFieldsProperty.GetAttributes: TPropertyAttributes;
begin
 Result := [paValueList];
end;

procedure TQRaFieldsProperty.GetValues(Proc: TGetStrProc);
var i: Integer;
    AField: TQRaDBText;
begin
   AField := GetComponent(0) as TQRaDBText;
   if AField <> nil then
   with AField do
   begin
    if (DataSet <> nil) then
      for i := 0 to DataSet.FieldCount-1 do
        Proc(DataSet.Fields[i].FieldName);
  end;
end;

end.
